Python Client for Google Cloud Translation
==========================================

    Python idiomatic client for `Google Cloud Translation`_

.. _Google Cloud Translation: https://cloud.google.com/translate/

|pypi| |versions|

-  `Documentation`_

.. _Documentation: https://googlecloudplatform.github.io/google-cloud-python/stable/translate-usage.html

Quick Start
-----------

.. code-block:: console

    $ pip install --upgrade google-cloud-translate

Authentication
--------------

With ``google-cloud-python`` we try to make authentication as painless as
possible. Check out the `Authentication section`_ in our documentation to
learn more. You may also find the `authentication document`_ shared by all
the ``google-cloud-*`` libraries to be helpful.

.. _Authentication section: http://google-cloud-python.readthedocs.io/en/latest/google-cloud-auth.html
.. _authentication document: https://github.com/GoogleCloudPlatform/gcloud-common/tree/master/authentication

Using the API
-------------

With the Google Cloud `Translation`_ API (`Translation API docs`_), you can
dynamically translate text between thousands of language pairs.

.. _Translation: https://cloud.google.com/translate/
.. _Translation API docs: https://cloud.google.com/translate/docs/apis

See the ``google-cloud-python`` API Translation `Documentation`_ to learn
how to translate text using this library.

.. |pypi| image:: https://img.shields.io/pypi/v/google-cloud-translate.svg
   :target: https://pypi.python.org/pypi/google-cloud-translate
.. |versions| image:: https://img.shields.io/pypi/pyversions/google-cloud-translate.svg
   :target: https://pypi.python.org/pypi/google-cloud-translate
